pywr.parameters.control\_curves.ControlCurveInterpolatedParameter
=================================================================

.. currentmodule:: pywr.parameters.control_curves

.. autoclass:: ControlCurveInterpolatedParameter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ControlCurveInterpolatedParameter.after
      ~ControlCurveInterpolatedParameter.before
      ~ControlCurveInterpolatedParameter.finish
      ~ControlCurveInterpolatedParameter.get_all_values
      ~ControlCurveInterpolatedParameter.get_double_lower_bounds
      ~ControlCurveInterpolatedParameter.get_double_upper_bounds
      ~ControlCurveInterpolatedParameter.get_double_variables
      ~ControlCurveInterpolatedParameter.get_integer_lower_bounds
      ~ControlCurveInterpolatedParameter.get_integer_upper_bounds
      ~ControlCurveInterpolatedParameter.get_integer_variables
      ~ControlCurveInterpolatedParameter.get_value
      ~ControlCurveInterpolatedParameter.load
      ~ControlCurveInterpolatedParameter.lower_bounds
      ~ControlCurveInterpolatedParameter.register
      ~ControlCurveInterpolatedParameter.reset
      ~ControlCurveInterpolatedParameter.set_double_variables
      ~ControlCurveInterpolatedParameter.set_integer_variables
      ~ControlCurveInterpolatedParameter.setup
      ~ControlCurveInterpolatedParameter.unregister
      ~ControlCurveInterpolatedParameter.update
      ~ControlCurveInterpolatedParameter.upper_bounds
      ~ControlCurveInterpolatedParameter.value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ControlCurveInterpolatedParameter.children
      ~ControlCurveInterpolatedParameter.comment
      ~ControlCurveInterpolatedParameter.control_curves
      ~ControlCurveInterpolatedParameter.double_size
      ~ControlCurveInterpolatedParameter.integer_size
      ~ControlCurveInterpolatedParameter.is_variable
      ~ControlCurveInterpolatedParameter.model
      ~ControlCurveInterpolatedParameter.name
      ~ControlCurveInterpolatedParameter.parents
      ~ControlCurveInterpolatedParameter.size
      ~ControlCurveInterpolatedParameter.storage_node
      ~ControlCurveInterpolatedParameter.values
   
   